@@ -4,46 +4,61 @@ Ask More Questions.
 Author: Ron Nathaniel
 """
 
-from typing import Generator
 from googlesearch import search
 
-from how.util import gen_next_n
 
-
-def ask_google(query: str, limit=20,) -> Generator:
+def ask_google(query: str, limit: int = 20) -> list:
     """
     Ask Google Anything.
     :param query: Query to google search
     :param limit: Total results to return
-    :return: Lazy Generator of result URIs
+    :return: List of result URIs
     """
+
     results = search(
         query,
-        stop=limit,
+        num_results=limit,
     )
 
     return results
 
 
-def ask_sof(query: str, limit=20, ) -> Generator:
+def ask_any(query: str, limit: int = 20, site: str = None) -> list:
+    """
+    Ask Any Site, Anything.
+    :param query: Query to search
+    :param limit: Total results to return
+    :param site: Site to search
+    :return: List of result URIs
+    """
+    if site:
+        query += ' site:' + site
+    results = ask_google(
+        query=query,
+        limit=limit,
+    )
+
+    return results
+
+
+def ask_sof(query: str, limit: int = 20) -> list:
     """
     Ask StackOverflow Anything.
     :param query: Query to StackOverflow search
     :param limit: Total results to return
-    :return: Lazy Generator of result URIs
+    :return: List of result URIs
     """
-    results = ask_google(
-        query=query + ' site:stackoverflow.com',
-        limit=limit
+    results = ask_any(
+        query=query,
+        limit=limit,
+        site='stackoverflow.com',
     )
 
     return results
 
 
 if __name__ == '__main__':
-    # Example Usage
+    # example usage
     res = ask_sof(
         'exit vi'
     )
-
-    print(gen_next_n(res, 5))
